"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _fs = _interopRequireDefault(require("fs"));

var _lru_map = require("lru_map");

var _File = _interopRequireDefault(require("./File"));

var _defaults = _interopRequireDefault(require("./defaults"));

// Copyright 2017-2019 @polkadot/client-db authors & contributors
// This software may be modified and distributed under the terms
// of the Apache-2.0 license. See the LICENSE file for details.
class Cache extends _File.default {
  constructor(base, file, options) {
    super(base, file, options);
    this._lruBranch = void 0;
    this._lruData = void 0;
    this._lruBranch = new _lru_map.LRUMap(_defaults.default.LRU_BRANCH_COUNT);
    this._lruData = new _lru_map.LRUMap(_defaults.default.LRU_DATA_COUNT);
  }

  _cacheBranch(branchAt, branch) {
    this._lruBranch.set(branchAt, branch);
  }

  _cacheData(dataAt, data) {
    this._lruData.set(dataAt, data);
  }

  _getCachedBranch(branchAt) {
    let branch = this._lruBranch.get(branchAt);

    if (!branch) {
      branch = Buffer.alloc(_defaults.default.BRANCH_SIZE);

      _fs.default.readSync(this._fd, branch, 0, _defaults.default.BRANCH_SIZE, branchAt);

      this._cacheBranch(branchAt, branch);
    }

    return branch;
  }

  _getCachedData(dataAt, length) {
    let data = this._lruData.get(dataAt);

    if (!data) {
      data = Buffer.alloc(length);

      _fs.default.readSync(this._fd, data, 0, length, dataAt);

      this._cacheData(dataAt, data);
    }

    return data;
  }

}

exports.default = Cache;