"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _fs = _interopRequireDefault(require("fs"));

var _path = _interopRequireDefault(require("path"));

var _util = require("@polkadot/util");

var _defaults = _interopRequireDefault(require("./defaults"));

var _Compact = _interopRequireDefault(require("./Compact"));

var _Impl = _interopRequireDefault(require("./Impl"));

// Copyright 2017-2019 @polkadot/client-db authors & contributors
// This software may be modified and distributed under the terms
// of the Apache-2.0 license. See the LICENSE file for details.
const l = (0, _util.logger)('db/flat');

class FileFlatDb extends _Impl.default {
  constructor(base) {
    let file = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : _defaults.default.DEFAULT_FILE;
    let options = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
    super(base, file, options);
  }

  open() {
    this.assertOpen(false);

    this._open(this._path);

    this._lruBranch.clear();

    this._lruData.clear();
  }

  close() {
    this.assertOpen();

    this._close();

    this._lruBranch.clear();

    this._lruData.clear();
  }

  drop() {
    this.assertOpen(false);

    _fs.default.unlinkSync(this._path);
  }

  empty() {
    this.assertOpen(false);

    this._open(this._path, true);
  }

  size() {
    return this._fileSize;
  }

  rename(base, file) {
    this.assertOpen(false);
    const oldPath = this._path;
    this._file = file;
    this._path = _path.default.join(base, file);

    _fs.default.renameSync(oldPath, this._path);
  }

  maintain(fn) {
    this.assertOpen(false);
    const compactor = new _Compact.default(this._file);
    compactor.maintain(fn);
  }

  del(key) {
    throw new Error('delete not implemented, only stubbed');
  }

  get(key) {
    this.assertOpen();
    l.debug(() => ['get', {
      key
    }]);
    const desc = this.findKey(this._serializeKey(key), false);

    if (!desc) {
      return null;
    }

    const result = this.readValue(desc);
    return result && result.value ? this._deserializeValue(result.value) : null;
  }

  put(key, value) {
    this.assertOpen();
    l.debug(() => ['set', {
      key,
      value
    }]);
    const desc = this.findKey(this._serializeKey(key), true);

    if (!desc) {
      throw new Error('Unable to create key');
    }

    this.writeValue(desc, this._serializeValue(value));
  }

  findKey(key, doCreate) {
    const result = this._findKey(key, doCreate, 0, 0);

    l.debug(() => ['findKey', {
      result
    }]);
    return result;
  }

  readValue(_ref) {
    let keyValue = _ref.keyValue;

    const result = this._readValue(keyValue);

    l.debug(() => ['readValue', {
      result
    }]);
    return result;
  }

  writeValue(_ref2, value) {
    let keyAt = _ref2.keyAt,
        keyValue = _ref2.keyValue;

    const result = this._writeValue(keyAt, keyValue, value);

    l.debug(() => ['writeValue', '=>', {
      result
    }]);
    return result;
  }

}

exports.default = FileFlatDb;