"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _fs = _interopRequireDefault(require("fs"));

var _mkdirp = _interopRequireDefault(require("mkdirp"));

var _util = require("@polkadot/util");

// Copyright 2017-2019 @polkadot/client-db authors & contributors
// This software may be modified and distributed under the terms
// of the Apache-2.0 license. See the LICENSE file for details.
const DIR_DEPTH = 1;
const l = (0, _util.logger)('db/tree');

class FileTreeDb {
  constructor(location) {
    this._location = void 0;
    this._location = location;
  }

  _getFilePath(key) {
    // NOTE We want to limit the number of entries in any specific directory. Split the
    // key into parts and use this to construct the path and the actual filename. We want
    // to limit the entries per directory, but at the same time minimize the number of
    // directories we need to create (when non-existent as well as the size overhead)
    const parts = (0, _util.u8aToHex)(key).match(/.{1,6}/g) || [];
    const directory = "".concat(this._location, "/").concat(parts.slice(0, DIR_DEPTH).join('/'));
    const file = "".concat(directory, "/").concat(parts.slice(DIR_DEPTH).join(''));
    return {
      directory,
      file
    };
  }

  open() {// noop
  }

  close() {// noop
  }

  drop() {
    l.error('drop() is not implemented');
  }

  empty() {
    l.error('empty() is not implemented');
  }

  rename(base, file) {
    l.error('rename() is not implemented');
  }

  size() {
    l.error('size() is not implemented');
    return 0;
  }

  maintain(fn) {
    fn({
      isCompleted: true,
      keys: 0,
      percent: 100
    });
  }

  del(key) {
    l.debug(() => ['del', {
      key
    }]);

    const _this$_getFilePath = this._getFilePath(key),
          file = _this$_getFilePath.file;

    if (_fs.default.existsSync(file)) {
      _fs.default.unlinkSync(file);
    }
  }

  get(key) {
    l.debug(() => ['get', {
      key
    }]);

    const _this$_getFilePath2 = this._getFilePath(key),
          file = _this$_getFilePath2.file;

    if (!_fs.default.existsSync(file)) {
      return null;
    }

    return (0, _util.bufferToU8a)(_fs.default.readFileSync(file));
  }

  put(key, value) {
    l.debug(() => ['set', {
      key,
      value
    }]);

    const _this$_getFilePath3 = this._getFilePath(key),
          directory = _this$_getFilePath3.directory,
          file = _this$_getFilePath3.file;

    if (!_fs.default.existsSync(directory)) {
      _mkdirp.default.sync(directory);
    }

    _fs.default.writeFileSync(file, (0, _util.u8aToBuffer)(value));
  }

}

exports.default = FileTreeDb;